@@ -24,7 +24,7 @@
 #define FILTERVIEW_H
 
 // Kasten gui
-#include <abstracttoolwidget.h>
+#include <kasten/abstracttoolwidget.h>
 
 class AbstractByteArrayFilterParameterSet;
 
