@@ -24,9 +24,9 @@
 #define BYTEARRAYVIEWPROFILELOCK_H
 
 // lib
-#include "bytearrayviewprofile.h"
+#include <kasten/okteta/bytearrayviewprofile.h>
 // Qt
-#include <QtCore/QSharedDataPointer>
+#include <QSharedDataPointer>
 
 class QString;
 
