@@ -48,6 +48,8 @@
 // KF5
 #include <KDBusService>
 #include <KLocalizedString>
+#include <KCrash>
+#include <kcoreaddons_version.h>
 // Qt
 #include <QCommandLineParser>
 #include <QList>
@@ -81,6 +83,9 @@ OktetaProgram::OktetaProgram( int &argc, char* argv[] )
 
     QApplication::setAttribute(Qt::AA_UseHighDpiPixmaps, true);
     KLocalizedString::setApplicationDomain( "okteta" );
+#if KCOREADDONS_VERSION >= 0x051500
+    KCrash::initialize();
+#endif
 }
 
 
@@ -95,8 +100,6 @@ int OktetaProgram::execute()
     KAboutData::setApplicationData( aboutData );
     QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("okteta")));
 
-    KDBusService programDBusService(KDBusService::Multiple | KDBusService::NoExitOnFailure);
-
     QCommandLineParser parser;
     aboutData.setupCommandLine(&parser);
     parser.addHelpOption();
@@ -113,6 +116,8 @@ int OktetaProgram::execute()
 
     aboutData.processCommandLine(&parser);
 
+    KDBusService programDBusService(KDBusService::Multiple | KDBusService::NoExitOnFailure);
+
     // TODO:
     mByteArrayViewProfileManager = new ByteArrayViewProfileManager();
     //mModelManagerManager->addModelManager( byteArrayViewProfileManager );
